@@ -4,6 +4,7 @@ from typing import Sequence, Tuple
 from django.db import models
 from django.db.models import OuterRef, Subquery
 
+from .orm_debug import DebugQS
 from .types import (
     ASC,
     BaseType,
@@ -14,7 +15,7 @@ from .types import (
     UnknownType,
     URLType,
 )
-from .util import annotation_path, s
+from .util import annotation_path
 
 
 @dataclass
@@ -31,11 +32,11 @@ class OrmBoundField:
 
     @property
     def path_str(self):
-        return s(self.full_path)
+        return "__".join(self.full_path)
 
     @property
     def queryset_path_str(self):
-        return s(self.queryset_path)
+        return "__".join(self.queryset_path)
 
     @property
     def group_by(self):
@@ -46,14 +47,18 @@ class OrmBoundField:
             return self.previous._lineage() + [self]
         return [self]
 
-    def annotate(self, request, qs):
+    def annotate(self, request, qs, debug=False):
         for field in self._lineage():
-            qs = field._annotate(request, qs)
+            qs = field._annotate(request, qs, debug=debug)
         return qs
 
-    def _annotate(self, request, qs):
+    def _annotate(self, request, qs, debug=False):
         return qs
 
+    def _annotate_qs(self, qs, expression):
+        assert "__" not in self.queryset_path_str
+        return qs.annotate(**{self.queryset_path_str: expression})
+
     def __getattr__(self, name):
         return getattr(self.field, name)
 
@@ -169,13 +174,15 @@ class OrmRawField(OrmConcreteField):
 
 
 class OrmCalculatedField(OrmBaseField):
-    def __init__(self, model_name, name, pretty_name, func):
+    def __init__(self, model_name, name, pretty_name, func, actions=None):
         if getattr(func, "boolean", False):
             type_ = BooleanType
         else:
             type_ = HTMLType
 
-        super().__init__(model_name, name, pretty_name, type_=type_, can_pivot=True)
+        super().__init__(
+            model_name, name, pretty_name, type_=type_, can_pivot=True, actions=actions
+        )
         self.func = func
 
     def bind(self, previous):
@@ -207,18 +214,24 @@ class OrmCalculatedField(OrmBaseField):
 
 
 class OrmBoundAnnotatedField(OrmBoundField):
-    def _annotate(self, request, qs):
+    def _annotate(self, request, qs, debug=False):
         from .orm_admin import admin_get_queryset
 
-        return qs.annotate(
-            **{
-                s(self.queryset_path): Subquery(
-                    admin_get_queryset(self.admin, request, [self.name])
-                    .filter(pk=OuterRef(s(self.previous.queryset_path + ["pk"])))
-                    .values(self.name)[:1],
-                    output_field=self.django_field,
-                )
-            }
+        if debug:
+            subquery = DebugQS("Subquery")
+            outer_ref = DebugQS("OuterRef")
+        else:
+            subquery = Subquery
+            outer_ref = OuterRef
+
+        return self._annotate_qs(
+            qs,
+            subquery(
+                admin_get_queryset(self.admin, request, [self.name], debug=debug)
+                .filter(pk=outer_ref("__".join(self.previous.queryset_path + ["pk"])))
+                .values(self.name)[:1],
+                output_field=self.django_field,
+            ),
         )
 
 
@@ -248,7 +261,7 @@ class OrmAnnotatedField(OrmBaseField):
             previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
-            queryset_path=annotation_path(full_path),
+            queryset_path=[annotation_path(full_path)],
             filter_=True,
         )
 
