@@ -49,7 +49,7 @@ _TYPE_FUNCTIONS = defaultdict(
 
 _month_choices = [
     (1, "January"),
-    (2, "Feburary"),
+    (2, "February"),
     (3, "March"),
     (4, "April"),
     (5, "May"),
