@@ -58,17 +58,17 @@ def _rows_sub_query(bound_query):
     )
 
 
-def get_result_queryset(request, bound_query):
+def get_result_queryset(request, bound_query, debug=False):
     all_fields = {f.queryset_path_str: f for f in bound_query.bound_fields}
     all_fields.update({f.queryset_path_str: f for f in bound_query.bound_filters})
 
     qs = bound_query.orm_model.get_queryset(
-        request, {f.split("__")[0] for f in all_fields}
+        request, {f.split("__")[0] for f in all_fields}, debug=debug
     )
 
     # sql functions and qs annotations
     for field in all_fields.values():
-        qs = field.annotate(request, qs)
+        qs = field.annotate(request, qs, debug=debug)
 
     # filter normal and sql function fields (aka __date)
     for filter_ in bound_query.valid_filters:
@@ -79,11 +79,11 @@ def get_result_queryset(request, bound_query):
     if not any(f.group_by for f in bound_query.bound_fields):
         return [
             qs.aggregate(
-                **dict(
-                    field.aggregate_clause
+                **{
+                    field.queryset_path_str: field.aggregate_clause
                     for field in bound_query.bound_fields + bound_query.bound_filters
                     if field.aggregate_clause
-                )
+                }
             )
         ]
 
@@ -94,11 +94,11 @@ def get_result_queryset(request, bound_query):
     qs = qs.values(*group_by_fields).distinct()
 
     # aggregates
-    aggregate_clauses = dict(
-        field.aggregate_clause
+    aggregate_clauses = {
+        field.queryset_path_str: field.aggregate_clause
         for field in bound_query.bound_fields + bound_query.bound_filters
         if field.aggregate_clause
-    )
+    }
     qs = qs.annotate(**aggregate_clauses)
 
     # having, aka filter aggregate fields
@@ -118,7 +118,7 @@ def get_result_queryset(request, bound_query):
     return qs[: bound_query.limit]
 
 
-def _get_result_list(request, bound_query):
+def get_result_list(request, bound_query):
     return list(get_result_queryset(request, bound_query))
 
 
@@ -215,15 +215,15 @@ def get_results(request, bound_query, orm_models, with_format_hints):
     if not bound_query.fields:
         return {"rows": [], "cols": [], "body": [], "length": 0}
 
-    res = _get_result_list(request, bound_query)
+    res = get_result_list(request, bound_query)
 
     if not res:
         return {"rows": [], "cols": [], "body": [], "length": 0}
 
     if bound_query.bound_col_fields and bound_query.bound_row_fields:
         # need to fetch rows and col titles seperately to get correct sort
-        rows_res = _get_result_list(request, _rows_sub_query(bound_query))
-        cols_res = _get_result_list(request, _cols_sub_query(bound_query))
+        rows_res = get_result_list(request, _rows_sub_query(bound_query))
+        cols_res = get_result_list(request, _cols_sub_query(bound_query))
     else:
         rows_res = res
         cols_res = res
