@@ -23,7 +23,7 @@ from .common import HttpResponse, JsonResponse, can_make_public, settings
 from .format_csv import get_csv_rows
 from .models import View
 from .orm_admin import OPEN_IN_ADMIN, get_models
-from .orm_results import get_result_queryset, get_results
+from .orm_results import get_result_list, get_result_queryset, get_results
 from .query import BoundQuery, Query, QueryFilter
 from .types import TYPES
 
@@ -159,16 +159,18 @@ def admin_action(request, model_name, fields):
         raise http.Http404(f"'{query.model_name}' does not exist")  # pragma: no cover
 
     bound_query = BoundQuery.bind(query, orm_models)
+    bound_field = bound_query.fields[0].orm_bound_field
 
-    results = get_results(request, bound_query, orm_models, False)
+    if not bound_field.field.actions or action not in bound_field.field.actions:
+        raise http.Http404(f"bad action '{action}'")  # pragma: no cover
 
-    pks = {row.get(field) for row in results["rows"]} | {
-        col.get(field) for col in results["cols"]
-    }
+    results = get_result_list(request, bound_query)
+
+    pks = {row[bound_field.queryset_path_str] for row in results}
     pks -= {None}
 
-    model_name = bound_query.fields[0].orm_bound_field.field.model_name
-    return orm_models[model_name].get_action_request(request, action, pks)
+    model_name = bound_field.field.model_name
+    return orm_models[model_name].get_http_request_for_action(request, action, pks)
 
 
 @csrf.csrf_protect
@@ -294,17 +296,23 @@ def _data_response(request, query, media, privileged=False, strict=False):
     elif privileged and media == "query":
         resp = _get_query_data(bound_query)
         return JsonResponse(resp)
-    elif privileged and media in ["sql", "explain"]:
-        query_set = get_result_queryset(request, bound_query)
+    elif privileged and media in ["sql", "explain", "qs"]:
+        query_set = get_result_queryset(request, bound_query, media == "qs")
         if isinstance(query_set, list):
             res = "Not available for pure aggregates"
         else:
             if media == "sql":
-                res = sqlparse.format(
+                res = "This is an approximation of the main query.\n"
+                res += "Pages with pivoted or calculated data may do additional queries.\n\n"
+                res += sqlparse.format(
                     str(query_set.query), reindent=True, keyword_case="upper"
                 )
             elif media == "explain":
                 res = query_set.explain()
+            elif media == "qs":
+                res = "This is an approximation of the main queryset.\n"
+                res += "Pages with pivoted or calculated data may do additional queries.\n\n"
+                res += str(query_set)
             else:
                 assert False
         return HttpResponse(res, content_type="text/plain")
