@@ -1,6 +1,6 @@
 import React, { useContext } from "react";
 import "./App.css";
-import { TLink, SLink, Overlay, syncPost, doPost } from "./Util";
+import { TLink, SLink, Overlay, syncPost, doPost, HasActionIcon } from "./Util";
 import { ShowContextMenu } from "./ContextMenu";
 
 function Spacer(props) {
@@ -84,6 +84,10 @@ function HeadCell(props) {
       ) : (
         " " + query.prettyPathStr(field.pathStr)
       )}
+      <HasActionIcon
+        modelField={modelField}
+        message="Admin actions availble on right click."
+      />
     </th>
   );
 }
@@ -138,21 +142,27 @@ function DataCell(props) {
 
   const showContextMenu = useContext(ShowContextMenu);
   function onContextMenu(e) {
-    showContextMenu(e, [
-      navigator.clipboard && {
-        name: "Copy",
-        fn: () => navigator.clipboard.writeText(formattedValue),
-      },
-      modelField.concrete &&
-        query.filterForValue(pathStr, value) && {
-          name: "Filter",
-          fn: () => query.addExactFilter(pathStr, value),
+    modelField.type !== "html" &&
+      showContextMenu(e, [
+        navigator.clipboard && {
+          name: "Copy",
+          fn: () => navigator.clipboard.writeText(formattedValue),
         },
-      fullRow && {
-        name: "Drill down",
-        fn: () => query.drillDown(fullRow),
-      },
-    ]);
+        modelField.concrete &&
+          query.filterForValue(pathStr, value) && {
+            name: "Filter",
+            fn: () => query.addExactFilter(pathStr, value),
+          },
+        modelField.concrete &&
+          query.filterForValue(pathStr, value) && {
+            name: "Exclude",
+            fn: () => query.addExactExclude(pathStr, value),
+          },
+        fullRow && {
+          name: "Drill down",
+          fn: () => query.drillDown(fullRow),
+        },
+      ]);
   }
 
   return (
